@@ -65,9 +65,8 @@ widget to be explained) got found.
 additional helper functions
 ---------------------------
 
-The helper functions :func:`anchor_points`, :func:`layout_ps_hints`, :func:`layout_x` and :func:`layout_y`, provided
-by this module, are providing a framework-independent calculation of the position and size of the help layout and the
-anchor.
+The helper functions :func:`anchor_layout_x`, :func:`anchor_layout_y`, :func:`anchor_points` and :func:`anchor_spec` are
+calculating framework-independent the position and direction of the a targeting tooltip anchor arrow and its layout box.
 
 
 flow change context message id
@@ -215,7 +214,7 @@ from ae.gui_app import (
     FLOW_KEY_SEP, flow_action, flow_class_name, flow_path_id, id_of_flow, update_tap_kwargs, MainAppBase)
 
 
-__version__ = '0.2.37'
+__version__ = '0.2.41'
 
 
 register_package_translations()
@@ -233,34 +232,69 @@ IGNORED_HELP_STATES = ('flow_id', 'flow_path', 'win_rectangle')     #: tuple of
 REGISTERED_TOURS = dict()                                           #: map(name: class) of all registered tour classes
 
 
-PsHintsType = Dict[str, Any]                                        #: actually Dict[str, Union[float, str]] but mypy...
+AnchorSpecType = Tuple[float, float, str]   #: TODO: Sphinx shows 'alias of' instead of this or the """ comment
+""" tooltip anchor specification tuple with the three items:
+
+* anchor_x (anchor center absolute x coordinate in window),
+* anchor_y (anchor center absolute y coordinate in window) and
+* anchor_dir (anchor direction: 'r'=right, 'i'=increase-y, 'l'=left, 'd'=decrease-y)
+
+.. note::
+    the direction in the y axis got named increase for higher y values
+    and `decrease` for lower y values to support different coordinate
+    systems of the GUI frameworks.
+
+    For example in `kivy` the zero value of the y axis is at the bottom
+    of the app window, whereas in enaml/qt it is at the top.
+"""
+
+ExplainedMatcherType = Union[Callable[[Any], bool], str]            #: single explained widget matcher type
 
 
-def anchor_points(font_size: float, ps_hints: PsHintsType) -> Tuple[float, ...]:
+def anchor_layout_x(anchor_spe: AnchorSpecType, layout_width: float, win_width: float) -> float:
+    """ calculate x position of the layout box of an anchor.
+
+    :param anchor_spe:      :data:`AnchorSpecType` tuple with anchor position and direction.
+    :param layout_width:    anchor layout width.
+    :param win_width:       app window width.
+    :return:                absolute x coordinate within the app window of anchor layout.
+    """
+    anchor_x, _anchor_y, anchor_dir = anchor_spe
+    if anchor_dir == 'l':
+        return anchor_x - layout_width
+    if anchor_dir == 'r':
+        return anchor_x
+    return min(max(0.0, anchor_x - layout_width / 2), win_width - layout_width)
+
+
+def anchor_layout_y(anchor_spe: AnchorSpecType, layout_height: float, win_height: float) -> float:
+    """ calculate y position of the layout box of an anchor.
+
+    :param anchor_spe:      :data:`AnchorSpecType` tuple with anchor position and direction.
+    :param layout_height:   anchor layout height.
+    :param win_height:      app window height.
+    :return:                absolute y coordinate in the app window of anchor layout.
+    """
+    _anchor_x, anchor_y, anchor_dir = anchor_spe
+    if anchor_dir == 'i':
+        return anchor_y
+    if anchor_dir == 'd':
+        return anchor_y - layout_height
+    return min(max(0.0, anchor_y - layout_height / 2), win_height - layout_height)
+
+
+def anchor_points(font_size: float, anchor_spe: AnchorSpecType) -> Tuple[float, ...]:
     """ recalculate points of the anchor triangle drawing.
 
     :param font_size:       font_size to calculate size (radius == hypotenuse / 2) of the anchor triangle.
-
-    :param ps_hints:        pos/size hints dict containing the three keys:
-                            anchor_x (anchor x coordinate in window),
-                            anchor_y (anchor y coordinate in window) and
-                            anchor_dir (anchor direction: 'r'=right, 'i'=increase-y, 'l'=left, 'd'=decrease-y)
-
-                            .. note:
-                                the direction in the y axis got named increase for higher y values
-                                and `decrease` for lower y values to support different coordinate
-                                systems of the GUI frameworks.
-
-                                For example in `kivy` the zero value of the y axis is at the bottom
-                                of the app window, whereas in enaml/qt it is at the top.
-
+    :param anchor_spe:      anchor specification tuple: x/y coordinates and direction - see :data:`AnchorSpecType`.
     :return:                tuple of the three x and y coordinates of the anchor triangle edges.
     """
-    if not ps_hints:
+    if not anchor_spe:
         return ()           # return empty tuple to prevent run-time-error at kv build/init
 
     radius = font_size * 0.69
-    anchor_x, anchor_y, anchor_dir = ps_hints['anchor_x'], ps_hints['anchor_y'], ps_hints['anchor_dir']
+    anchor_x, anchor_y, anchor_dir = anchor_spe
     return (anchor_x - (radius if anchor_dir in 'id' else 0),
             anchor_y - (radius if anchor_dir in 'lr' else 0),
             anchor_x + (0 if anchor_dir in 'id' else radius * (-1 if anchor_dir == 'r' else 1)),
@@ -270,6 +304,42 @@ def anchor_points(font_size: float, ps_hints: PsHintsType) -> Tuple[float, ...]:
             )
 
 
+def anchor_spec(wid_x: float, wid_y: float, wid_width: float, wid_height: float, win_width: float, win_height: float
+                ) -> AnchorSpecType:
+    """ calculate anchor center pos (x, y) and anchor direction to the targeted widget.
+
+    :param wid_x:           absolute x coordinate in app window of targeted widget.
+    :param wid_y:           absolute y coordinate in app window of targeted widget.
+    :param wid_width:       width of targeted widget.
+    :param wid_height:      height of targeted widget.
+    :param win_width:       app window width.
+    :param win_height:      app window height.
+    :return:                :data:`AnchorSpecType` tuple with anchor position and direction.
+    """
+    max_width = win_width - wid_x - wid_width
+    if max_width < wid_x:
+        max_width = wid_x
+        anchor_dir_x = 'l'
+    else:
+        anchor_dir_x = 'r'
+    max_height = win_height - wid_y - wid_height
+    if max_height < wid_y:
+        max_height = wid_y
+        anchor_dir_y = 'd'
+    else:
+        anchor_dir_y = 'i'
+    if max_width > max_height:
+        anchor_dir = anchor_dir_x
+        anchor_x = wid_x + (0 if anchor_dir_x == 'l' else wid_width)
+        anchor_y = wid_y + wid_height / 2
+    else:
+        anchor_dir = anchor_dir_y
+        anchor_x = wid_x + wid_width / 2
+        anchor_y = wid_y + (0 if anchor_dir_y == 'd' else wid_height)
+
+    return anchor_x, anchor_y, anchor_dir
+
+
 def help_id_tour_class(help_id: str) -> Optional[Any]:
     """ determine the tour class if passed help id has attached tour pages.
 
@@ -326,86 +396,6 @@ def id_of_tour_help(page_id: str) -> str:
     return f'{TOUR_PAGE_HELP_ID_PREFIX}{page_id}'
 
 
-def layout_ps_hints(wid_x: float, wid_y: float,
-                    wid_width: float, wid_height: float,
-                    win_width: float, win_height: float) -> PsHintsType:
-    """ recalculate anchor and max width/height on change of widget pos/size or window size.
-
-    :param wid_x:           x coordinate in app window of help target flow widget.
-    :param wid_y:           y coordinate in app window of help target flow widget.
-    :param wid_width:       width of help target flow widget.
-    :param wid_height:      height of help target flow widget.
-    :param win_width:       app window width.
-    :param win_height:      app window height.
-    :return:                dict with position and size hints, like e.g.:
-
-                            * anchor_dir:       direction of the anchor triangle (pointing from help layout
-                                                to the help target widget):
-                                                'r'=right, 'i'=increase-y, 'l'=left, 'd'=decrease-y(kivy:bottom/qt:top).
-                            * anchor_x:         x coordinate of the anchor center.
-                            * anchor_y:         y coordinate of the anchor center.
-                            * max_width:        maximum width of the layout.
-                            * max_height:       maximum height of the layout.
-
-    """
-    max_width = win_width - wid_x - wid_width
-    if max_width < wid_x:
-        max_width = wid_x
-        anchor_dir_x = 'l'
-    else:
-        anchor_dir_x = 'r'
-    max_height = win_height - wid_y - wid_height
-    if max_height < wid_y:
-        max_height = wid_y
-        anchor_dir_y = 'd'
-    else:
-        anchor_dir_y = 'i'
-    if max_width > max_height:
-        anchor_dir = anchor_dir_x                                       # pylint: disable=possibly-unused-variable
-        anchor_x = wid_x + (0 if anchor_dir_x == 'l' else wid_width)    # pylint: disable=possibly-unused-variable
-        anchor_y = wid_y + wid_height / 2                               # pylint: disable=possibly-unused-variable
-        max_height = win_height
-    else:
-        anchor_dir = anchor_dir_y
-        anchor_x = wid_x + wid_width / 2
-        anchor_y = wid_y + (0 if anchor_dir_y == 'd' else wid_height)
-        max_width = win_width
-
-    return locals().copy()
-
-
-def layout_x(anchor_x: float, anchor_dir: str, width: float, win_width: float) -> float:
-    """ recalculate help layout x position.
-
-    :param anchor_x:        anchor x coordinate in window.
-    :param anchor_dir:      anchor direction: 'r'=right, 'i'=increase-y, 'l'=left, 'd'=decrease-y (kivy:bottom, qt:top).
-    :param width:           help layout width.
-    :param win_width:       app window width.
-    :return:                x coordinate of help layout within the app window.
-    """
-    if anchor_dir == 'l':
-        return anchor_x - width
-    if anchor_dir == 'r':
-        return anchor_x
-    return min(max(0.0, anchor_x - width / 2), win_width - width)
-
-
-def layout_y(anchor_y: float, anchor_dir: str, height: float, win_height: float) -> float:
-    """ recalculate help layout y position.
-
-    :param anchor_y:        anchor y coordinate in window.
-    :param anchor_dir:      anchor direction: 'r'=right, 'i'=increase-y, 'l'=left, 'd'=decrease-y (kivy:bottom, qt:top).
-    :param height:          help layout height.
-    :param win_height:      app window height.
-    :return:                y coordinate of help layout in the app window.
-    """
-    if anchor_dir == 'i':
-        return anchor_y
-    if anchor_dir == 'd':
-        return anchor_y - height
-    return min(max(0.0, anchor_y - height / 2), win_height - height)
-
-
 def register_tour_class(tour_class: Type['TourBase']):
     """ register app tour class.
 
@@ -448,15 +438,17 @@ def translation_short_help_id(help_id: str) -> Tuple[Optional[Union[str, Dict[st
     return trans_text_or_dict, short_help_id
 
 
-def widget_page_id(wid: Any) -> str:
+def widget_page_id(wid: Optional[Any]) -> str:
     """ determine tour page id of passed widget.
 
-    :param wid:                 widget to determine tour page id from.
-    :return:                    tour page id or empty string if widget has no page id.
+    :param wid:                 widget to determine tour page id from (can be None).
+    :return:                    tour page id or empty string if widget has no page id or is None.
     """
     page_id = getattr(wid, 'tap_flow_id', '')
     if not page_id:
         page_id = getattr(wid, 'app_state_name', '')
+        if not page_id:
+            page_id = getattr(wid, 'focus_flow_id', '')
     return page_id
 
 
@@ -504,20 +496,33 @@ class TourBase:
         * `app_flow_delay`: time in seconds to wait until app flow change is completed (def=1.2, >0.9 for auto-width).
         * `app_reset_delay`: time in seconds between app reset/close-popups and flow reset/prepare-tour-page (def=0.3).
         * `back_text`: caption of tour previous page button (def=get_text('back')).
+        * `fade_out_app`: set to 0.0 to prevent the fade out of the app screen (def=1.0).
         * `help_vars`: additional help variables, e.g. `help_translation` providing context help translation dict/text.
         * `next_text`: caption of tour next page button (def=get_text('next')).
         * `next_page_delay`: time in seconds to read the current page before next request_auto_page_switch() (def=9.6).
+        * `page_update_delay`: time in seconds to wait until tour layout/overlay is completed (def=0.9).
         * `tip_text` or (empty string): tour page tooltip text fstring message text template.
         """
 
         self.page_ids: List[str] = list()
         """ list of tour page ids, either initialized via this class attribute or dynamically. """
 
-        self.pages_explained_matcher: Dict[str, Union[Callable[[Any], bool], str]] = dict()
-        """ :meth:`MainAppBase.find_widget` match callable to determine explained widget of each tour page. """
+        self.pages_explained_matchers: Dict[str, Union[ExplainedMatcherType, Tuple[ExplainedMatcherType, ...]]] = dict()
+        """ matchers (specified as callable or id-string) to determine the explained widget(s) of each tour page.
 
-        self.page_idx: int = 0                      #: index to the current tour page (in :attr:`.page_ids`)
-        self.last_page_idx: Optional[int] = None    #: last tour page index (None on tour start)
+        each key of this dict is a tour page id (for which the explained widget(s) will be determined automatically).
+
+        to explain a single widget instance, specify a dict value that is either a :meth:`MainAppBase.find_widget` match
+        callable, or an evaluation expression resulting in such callable, or an id matching the returned string of
+        :func:`widget_page_id` of a visible widget. the callable get called for each widget in the widget tree with a
+        single argument specifying the widget instance, returning True for the widget to explain/target/highlight.
+
+        to explain/target/highlight instead the minimum enclosing rectangle of multiple widgets, specify the value of
+        this dict as tuple of such matchers/id-strings (one tuple item for each widget to include).
+        """
+
+        self.page_idx: int = 0                      #: index of the current tour page (in :attr:`.page_ids`)
+        self.last_page_idx: Optional[int] = None    #: last tour page index (`None` on tour start)
 
         self.main_app = main_app                    #: shortcut to main app instance
         self.layout = main_app.tour_layout          #: tour overlay layout instance
@@ -643,51 +648,73 @@ class TourBase:
         """ setup app flow and load page data to prepare a tour page. """
         self.main_app.vpo(f"TourBase.setup_app_flow page_data={self.page_data}")
 
+        self.update_page_ids()
         self.load_page_data()
 
         app_flow_delay = self.page_data.get('app_flow_delay', 1.2)  # > 0.9 to complete auto width animation
         self._delayed_setup_layout_call = self.main_app.call_method_delayed(app_flow_delay, self.setup_layout)
 
-    def setup_explained_widget(self):
-        """ determine and set the explained widget for the actual tour page. """
+    def setup_explained_widget(self) -> list:
+        """ determine and set the explained widget for the actual tour page.
+
+        :return:                list of explained widget instances.
+        """
         main_app = self.main_app
+        layout: Any = self.layout
+        wid = main_app.help_activator       # fallback widget
+        widgets = list()
         page_id = self.page_ids[self.page_idx]
-        if page_id in self.pages_explained_matcher:
-            matcher = self.pages_explained_matcher[page_id]
-            if isinstance(matcher, str):
-                matcher = try_eval(matcher, glo_vars=main_app.global_variables(layout=self.layout, tour=self))
-            wid = main_app.find_widget(matcher)
-            self.page_data['help_vars']['help_translation'] = tour_help_translation(widget_page_id(wid))
+        if page_id in self.pages_explained_matchers:
+            matcher = self.pages_explained_matchers[page_id]
+            matchers = matcher if isinstance(matcher, (list, tuple)) else (matcher, )
+            for matcher in matchers:
+                if isinstance(matcher, str):
+                    match_str = matcher
+                    matcher = try_eval(match_str, ignored_exceptions=(Exception, ),     # NameError, SyntaxError, ...
+                                       glo_vars=main_app.global_variables(layout=layout, tour=self))
+                    if not callable(matcher):
+                        matcher = lambda widget: widget_page_id(widget) == match_str    # noqa: E731
+                widgets.append(main_app.find_widget(matcher))
+            if len(widgets) > 1:
+                wid = layout.explained_placeholder
+                wid.x, wid.y, wid.width, wid.height = main_app.widgets_enclosing_rectangle(widgets)
+            elif widgets:
+                wid = widgets[0]
         else:
-            wid = main_app.widget_by_flow_id(page_id)
-            if not wid:
-                wid = main_app.widget_by_app_state_name(page_id)
-        if wid:
-            self.layout.explained_widget = wid
+            wid = main_app.widget_by_flow_id(page_id) or main_app.widget_by_app_state_name(page_id) or wid
+
+        if not widgets:
+            widgets.append(wid)
+
+        self.page_data['help_vars']['help_translation'] = tour_help_translation(widget_page_id(wid))
+        layout.explained_pos = main_app.widget_pos(wid)
+        layout.explained_size = main_app.widget_size(wid)
+        layout.explained_widget = wid
+
+        return widgets
 
     def setup_layout(self):
         """ setup/prepare tour overlay/layout after switch of tour page. """
         self._delayed_setup_layout_call = None
         main_app = self.main_app
         layout = self.layout
+        main_app.vpo(f"TourBase.setup_layout(): page id={self.page_ids[self.page_idx]}")
 
         try:
             self.top_popup = main_app.popups_opened()[-1]
         except IndexError:
             self.top_popup = None
 
-        self.update_page_ids()
-        main_app.vpo(f"TourBase.setup_layout(): page id={self.page_ids[self.page_idx]}")
-
         self.setup_explained_widget()
         self.setup_texts()
-        layout.page_updated()
 
         main_app.ensure_top_most_z_index(layout)
 
         if self.auto_switch_pages:
             self.request_auto_page_switch()
 
+        main_app.call_method_delayed(self.page_data.get('page_update_delay', 0.9), layout.page_updated)
+
     def setup_texts(self):
         """ setup texts in tour layout from page_data. """
         main_app = self.main_app
@@ -696,8 +723,8 @@ class TourBase:
         page_idx = self.page_idx
 
         glo_vars = main_app.global_variables(layout=layout, tour=self)
-        if self.layout.explained_widget:
-            glo_vars['self'] = self.layout.explained_widget
+        if layout.explained_widget:
+            glo_vars['self'] = layout.explained_widget
         if self.top_popup:
             glo_vars['root'] = self.top_popup
 
@@ -741,11 +768,10 @@ class TourBase:
         self.restore_app_states()
 
     def update_page_ids(self):
-        """ update/change page ids after app flow setup and before the tour overlay/layout setup.
+        """ update/change page ids on app flow setup (before tour page loading and the tour overlay/layout setup).
 
-        override this method to change the page_ids in a running tour. don't forget to reload the page data (by calling
-        :meth:`.load_page_data`) if you remove/replace the current page, or to correct/decrement the attribute values
-        of :attr:`.last_page_idx` and :attr:`.page_idx` if you remove a page which is preceding the current page.
+        override this method to dynamically change the page_ids in a running tour. after adding/removing a page the
+        attribute values of :attr:`.last_page_idx` and :attr:`.page_idx` have to be corrected accordingly.
         """
         self.main_app.vpo(f"TourBase.update_page_ids {self.page_ids}")
 
@@ -762,9 +788,9 @@ class TourDropdownFromButton(TourBase):
             if flow_action(last_page_id) == 'open':
                 self.main_app.change_flow(last_page_id, **update_tap_kwargs(self.layout.explained_widget))
 
-        elif self.last_page_idx == 1 and self.page_idx == 0:
-            if self.top_popup and flow_action(self.page_ids[self.page_idx]) == 'open':
-                self.top_popup.close()
+        elif self.last_page_idx == 1 and self.page_idx == 0 \
+                and self.top_popup and flow_action(self.page_ids[self.page_idx]) == 'open':
+            self.top_popup.close()
 
     def update_page_ids(self):
         """ prepare all tour pages - first page is explaining opening dropdown button. """
@@ -784,8 +810,6 @@ class TourDropdownFromButton(TourBase):
             page_ids.remove(TourDropdownFromButton.determine_page_ids)
             page_ids.extend(children)
 
-            self.load_page_data()   # reload page data of this 2nd tour page (explaining the first dropdown child)
-
 
 # ====== app tours =============================================================
 
@@ -805,9 +829,9 @@ class OnboardingTour(TourBase):
             '', 'page_switching', 'responsible_layout', 'tip_help_intro', 'tip_help_tooltip', 'layout_font_size',
             'tour_end', 'user_registration'])
 
-        self.pages_explained_matcher.update(dict(
+        self.pages_explained_matchers.update(dict(
             tip_help_intro=lambda widget: widget.__class__.__name__ == 'HelpToggler',
-            tip_help_tooltip=lambda widget: getattr(widget, 'tap_flow_id', None) == _OPEN_USER_PREFERENCES_FLOW_ID,
+            tip_help_tooltip=_OPEN_USER_PREFERENCES_FLOW_ID,
             layout_font_size=lambda widget: getattr(widget, 'app_state_name', None) == 'font_size',
         ))
 
@@ -830,19 +854,19 @@ class OnboardingTour(TourBase):
             self.main_app.change_flow(id_of_flow('open', 'user_name_editor'))
 
     def teardown_app_flow(self):
-        """ overridden to close the opened user preferences dropdown on leaving responsible_layout tour page. """
-        super().teardown_app_flow()
+        """ overridden to close the opened user preferences dropdown on leaving layout_font_size tour page. """
         if self.top_popup and self.page_ids[self.page_idx] == 'layout_font_size':
             self.top_popup.close()
+        super().teardown_app_flow()
 
     def update_page_ids(self):
         """ overridden to remove page (only showing once). """
         super().update_page_ids()
-        if self.last_page_id == 'page_switching':
+        if 'page_switching' in self.page_ids and self.last_page_id:  # last page id not in (None=tour-start,''=1st page)
+            # remove page_switching if not at onboarding startup or after switch from first page to the next one
             self.page_ids.remove('page_switching')
-            if self.last_page_idx == self.page_idx - 1:
-                self.last_page_idx -= 1
-                self.page_idx -= 1
+            self.last_page_idx -= 1
+            self.page_idx -= 1
 
 
 class UserPreferencesTour(TourDropdownFromButton):
@@ -861,7 +885,6 @@ class HelpAppBase(MainAppBase, ABC):
     displayed_help_id: str = ''                 #: message id of currently explained/focused target widget in help mode
     help_activator: Any = None                  #: help mode de-/activator button widget
     help_layout: Optional[Any] = None           #: help text container widget in active help mode else None
-    onboarding_tour_class: Type[OnboardingTour] = OnboardingTour    #: default onboarding app tour class
     tour_layout: Optional[Any] = None           #: tour layout/overlay widget in active tour mode else None
     tour_overlay_class: Optional[Type] = None   #: UI-framework-specific tour overlay class, set by main app sub-class
 
@@ -920,10 +943,10 @@ class HelpAppBase(MainAppBase, ABC):
         if count is not None:
             help_vars['count'] = count
 
-        if not self.help_flow_display(help_vars):
-            if super().change_flow(new_flow_id, **event_kwargs):
-                self.help_flow_display(help_vars, changed=True)
-                return True
+        if not self.help_flow_display(help_vars) and super().change_flow(new_flow_id, **event_kwargs):
+            self.help_flow_display(help_vars, changed=True)
+            return True
+
         return False
 
     # help specific methods
@@ -946,11 +969,8 @@ class HelpAppBase(MainAppBase, ABC):
 
         help_id = id_of_state_help(app_state_name)
 
-        hlw = self.help_layout
-        if hlw is None:
-            if translation_short_help_id(help_id)[0]:
-                self._next_help_id = help_id
-            return False            # inactive help layout
+        if self.help_is_inactive(help_id):
+            return False
 
         ret = self.help_display(help_id, help_vars, key_suffix='after' if changed else '')
         if help_id == self.displayed_help_id and not changed:
@@ -988,10 +1008,12 @@ class HelpAppBase(MainAppBase, ABC):
         glo_vars = self.global_variables()
         hlw: Any = self.help_layout
         hlw.tip_text = get_f_string(short_help_id, key_suffix=key_suffix, glo_vars=glo_vars, loc_vars=help_vars)
-        hlw.explained_widget = self.help_widget(help_id, help_vars)     # set help target widget
+        hlw.targeted_widget = self.help_widget(help_id, help_vars)     # set help target widget
 
         self.ensure_top_most_z_index(hlw)
         self.change_observable('displayed_help_id', help_id)
+        self._next_help_id = ''
+
         self.call_method_delayed(0.12, 'on_help_displayed')
 
         return True
@@ -1015,11 +1037,7 @@ class HelpAppBase(MainAppBase, ABC):
             help_vars['self'] = wid                         # set help widget to opening button after closing popup
 
         help_id = id_of_flow_help(flow_id)
-
-        hlw = self.help_layout
-        if hlw is None:
-            if translation_short_help_id(help_id)[0]:
-                self._next_help_id = help_id
+        if self.help_is_inactive(help_id):
             return False            # inactive help layout
 
         key_suffix = 'after' if changed and not self._closing_popup_open_flow_id else ''
@@ -1030,6 +1048,19 @@ class HelpAppBase(MainAppBase, ABC):
             ret = False
         return ret
 
+    def help_is_inactive(self, help_id: str) -> bool:
+        """ check if help mode is inactive and reserve/note-down current help id for next help mode activation.
+
+        :param help_id:         help id to be reserved for next help activation with empty help id.
+        :return:                True if help mode is inactive, else False.
+        """
+        hlw = self.help_layout
+        if hlw is None:
+            if translation_short_help_id(help_id)[0]:
+                self._next_help_id = help_id
+            return True            # inactive help layout
+        return False
+
     def help_target_and_id(self, help_vars: Dict[str, Any]) -> Tuple[Any, str]:
         """ find help widget/target and help id on help mode activation.
 
@@ -1094,7 +1125,7 @@ class HelpAppBase(MainAppBase, ABC):
         return super().key_press_from_framework(modifiers, key)
 
     def on_app_started(self):
-        """ last app init event on app startup. """
+        """ optional app init event - the last on app startup. """
         if self.user_id not in self.registered_users:
             self.start_app_tour()
 
@@ -1109,11 +1140,6 @@ class HelpAppBase(MainAppBase, ABC):
             self.help_display('', dict())
         return True
 
-    def on_help_displayed(self):
-        """ default post help display event handler for to update the window pos of the explained widget. """
-        hlw = self.help_layout
-        hlw.explained_pos = hlw.explained_widget.to_window(*hlw.explained_widget.pos)
-
     def save_app_states(self) -> str:
         """ override MainAppBase method to not overwrite app states if app tour is active. """
         if self.tour_layout:
